package
Version:
v0.0.0-...-9b90cfe
Opens a new window with list of versions in this module.
Published: Aug 3, 2014
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type Author struct {
Name string `json:"name"`
Email string `json:"email"`
}
type Commit struct {
Id string `json:"id"`
Url string `json:"url"`
Message string `json:"message"`
Timestamp string `json:timestamp`
Author *Author `json:"author"`
Added []string `json:"added"`
}
type CommitRepo struct {
Url string `json:"url"`
Name string `json:"name"`
Desc string `json:"description"`
Owner *Owner `json:"owner"`
}
type Owner struct {
Type string `json:"type"`
Login string `json:"login"`
Name string `json:"name"`
}
Owner represents the owner of a Github Repository.
type PostReceiveHook struct {
Before string `json:"before"`
After string `json:"after"`
Ref string `json:"ref"`
Repo *CommitRepo `json:"repository"`
Commits []*Commit `json:"commits"`
Head *Commit `json:"head_commit"`
Deleted bool `json:"deleted"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.